HawkREST
========
.. image:: https://img.shields.io/pypi/v/hawkrest.svg
    :target: https://pypi.python.org/pypi/hawkrest
    :alt: Latest PyPI release

.. image:: https://img.shields.io/pypi/dm/hawkrest.svg
    :target: https://pypi.python.org/pypi/hawkrest
    :alt: PyPI monthly download stats

.. image:: https://travis-ci.org/kumar303/hawkrest.svg?branch=master
    :target: https://travis-ci.org/kumar303/hawkrest
    :alt: Travis master branch status

.. image:: https://readthedocs.org/projects/hawkrest/badge/?version=latest
    :target: https://hawkrest.readthedocs.org/en/latest/?badge=latest
    :alt: Documentation status


`Hawk`_ HTTP Authorization for `Django Rest Framework`_.

.. _`Hawk`: https://github.com/hueniverse/hawk
.. _`Django Rest Framework`: http://django-rest-framework.org/

Full documentation: https://hawkrest.readthedocs.org/
